#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.1
id: x509-store-1.6.1-43851738bccd019b67ff937f268f43a7
key: x509s_6AuJwaGKgg97ff0M26wTI0
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/x509-store-1.6.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/x509-store-1.6.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/x509-store-1.6.1
hs-libraries: HSx509-store-1.6.1-6AuJwaGKgg97ff0M26wTI0
depends:
    asn1-encoding-0.9.3-fec344bb54bb5da4bfe7deb0a3562b73
    asn1-types-0.3.2-0a9b49f98bdd53624b82b3c86ed41efa
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptonite-0.15-52f487cbd51518538a9e7cbc4eddf82b
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pem-0.2.2-5f6df2ca3b7f68abc9010881cb82b5dd
    x509-1.6.3-ea92228b2bfea35f7dd001d2924d4ebd
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
